spindry.SupraMolecule
=====================

.. currentmodule:: spindry

.. autoclass:: SupraMolecule
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~SupraMolecule.get_cid
      ~SupraMolecule.get_components
      ~SupraMolecule.get_potential
      ~SupraMolecule.init_from_components
      ~SupraMolecule.with_displacement
      ~SupraMolecule.with_position_matrix
      ~SupraMolecule.write_xyz_content
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SupraMolecule.cid
      ~SupraMolecule.potential
      ~SupraMolecule.atoms
      ~SupraMolecule.bonds
      ~SupraMolecule.position_matrix
   
   